@@ -176,6 +176,25 @@ def test_build_quiet(mocker, tuxbuild_config):
     assert result.output == "https://tuxbuild.example.com/abcdef0123456789\n"
 
 
+def test_build_git_sha(mocker, tuxbuild_config):
+    build = mocker.patch("tuxbuild.build.Build.build")
+    wait_for_object = mocker.patch("tuxbuild.cli.wait_for_object")
+    runner = CliRunner()
+    result = runner.invoke(
+        tuxbuild.cli.build,
+        [
+            "--git-repo=https://git.example.com/linux.git",
+            "--git-sha=beefbee",
+            "--target-arch=arm64",
+            "--kconfig=defconfig",
+            "--toolchain=gcc-9",
+        ],
+    )
+    assert result.exit_code == 0
+    assert build.call_count == 1
+    assert wait_for_object.call_count == 1
+
+
 sample_build_set = """
 sets:
   - name: test
@@ -189,22 +208,34 @@ sets:
       - {target_arch: x86, toolchain: gcc-9, kconfig: allyesconfig}
       - {target_arch: i386, toolchain: gcc-9, kconfig: allmodconfig}
       - {target_arch: riscv, toolchain: gcc-9, kconfig: allyesconfig}
+  - name: arch-matrix
+    builds:
+      - {target_arch: arm64,  toolchain: gcc-9}
+      - {target_arch: arm,    toolchain: gcc-9}
+      - {target_arch: i386,   toolchain: gcc-9}
+      - {target_arch: riscv,  toolchain: gcc-9}
+      - {target_arch: x86,    toolchain: gcc-9}
 """
 
 
-def test_build_set(mocker, tmp_path, tuxbuild_config):
-    build = mocker.patch("tuxbuild.build.BuildSet.build")
-    wait_for_object = mocker.patch("tuxbuild.cli.wait_for_object")
-    runner = CliRunner()
+@pytest.fixture
+def tux_config(tmp_path):
     config = tmp_path / "buildset.yaml"
     with config.open("w") as f:
         f.write(sample_build_set)
+    return config
+
+
+def test_build_set(mocker, tuxbuild_config, tux_config):
+    build = mocker.patch("tuxbuild.build.BuildSet.build")
+    wait_for_object = mocker.patch("tuxbuild.cli.wait_for_object")
+    runner = CliRunner()
     result = runner.invoke(
         tuxbuild.cli.build_set,
         [
             "--git-repo=https://git.example.com/linux.git",
             "--git-ref=master",
-            f"--tux-config={config}",
+            f"--tux-config={tux_config}",
             "--set-name=test",
         ],
     )
@@ -213,7 +244,27 @@ def test_build_set(mocker, tmp_path, tuxbuild_config):
     assert wait_for_object.call_count == 9
 
 
-def test_build_set_quiet(mocker, tmp_path, tuxbuild_config):
+def test_build_set_no_kconfig(mocker, tuxbuild_config, tux_config):
+    build = mocker.patch("tuxbuild.build.BuildSet.build")
+    wait_for_object = mocker.patch("tuxbuild.cli.wait_for_object")
+    runner = CliRunner()
+    result = runner.invoke(
+        tuxbuild.cli.build_set,
+        [
+            "--git-repo=https://git.example.com/linux.git",
+            "--git-ref=master",
+            f"--tux-config={tux_config}",
+            "--set-name=arch-matrix",
+            "--quiet",
+        ],
+    )
+    build.assert_not_called()
+    wait_for_object.assert_not_called()
+    assert result.exit_code == 1
+    assert "kconfig is mandatory" in result.output
+
+
+def test_build_set_quiet(mocker, tuxbuild_config, tux_config):
     BuildSet = mocker.patch("tuxbuild.build.BuildSet")
     builds = []
     for i in range(1, 10):
@@ -223,15 +274,12 @@ def test_build_set_quiet(mocker, tmp_path, tuxbuild_config):
     BuildSet.return_value.build_objects = builds
     mocker.patch("tuxbuild.cli.wait_for_object")
     runner = CliRunner()
-    config = tmp_path / "buildset.yaml"
-    with config.open("w") as f:
-        f.write(sample_build_set)
     result = runner.invoke(
         tuxbuild.cli.build_set,
         [
             "--git-repo=https://git.example.com/linux.git",
             "--git-ref=master",
-            f"--tux-config={config}",
+            f"--tux-config={tux_config}",
             "--set-name=test",
             "--quiet",
         ],
@@ -239,3 +287,22 @@ def test_build_set_quiet(mocker, tmp_path, tuxbuild_config):
     assert result.exit_code == 0
     output = "".join([f"https://tuxbuild.example.com/{i}\n" for i in range(1, 10)])
     assert result.output == output
+
+
+def test_build_set_git_sha(mocker, tuxbuild_config, tux_config):
+    build = mocker.patch("tuxbuild.build.BuildSet.build")
+    wait_for_object = mocker.patch("tuxbuild.cli.wait_for_object")
+    runner = CliRunner()
+    result = runner.invoke(
+        tuxbuild.cli.build_set,
+        [
+            "--git-repo=https://git.example.com/linux.git",
+            "--git-sha=beefbee",
+            f"--tux-config={tux_config}",
+            "--set-name=test",
+            "--quiet",
+        ],
+    )
+    assert result.exit_code == 0
+    assert build.call_count == 1
+    assert wait_for_object.call_count == 9
