@@ -62,7 +62,8 @@ def get_request(url, headers):
 @attrs(kw_only=True)
 class Build:
     git_repo = attrib()
-    git_ref = attrib()
+    git_ref = attrib(default=None)
+    git_sha = attrib(default=None)
     target_arch = attrib()
     kconfig = attrib()
     toolchain = attrib()
@@ -109,7 +110,10 @@ class Build:
         """ return a build data in a python dict """
         build_entry = {}
         build_entry["git_repo"] = self.git_repo
-        build_entry["git_ref"] = self.git_ref
+        if self.git_ref:
+            build_entry["git_ref"] = self.git_ref
+        if self.git_sha:
+            build_entry["git_sha"] = self.git_sha
         build_entry["target_arch"] = self.target_arch
         build_entry["toolchain"] = self.toolchain
         build_entry["kconfig"] = self.kconfig
@@ -119,13 +123,17 @@ class Build:
 
     def verify_build_parameters(self):
         """ Pre-check the build arguments """
+        assert self.git_repo, "git_repo is mandatory"
         assert self.is_supported_git_url(
             self.git_repo
         ), "git url must be in the form of git:// or http:// or https://"
-        assert self.git_ref is not None
-        assert self.target_arch is not None
-        assert self.kconfig is not None
-        assert self.headers is not None
+        assert (self.git_ref and not self.git_sha) or (
+            self.git_sha and not self.git_ref
+        ), "Either a git_ref or a git_sha is required"
+        assert self.target_arch is not None, "target_arch is mandatory"
+        assert self.kconfig, "kconfig is mandatory"
+        assert self.toolchain, "toolchain is mandatory"
+        assert self.headers is not None, "headers is mandatory"
 
     def build(self):
         """ Submit the build request """
