@@ -154,70 +154,75 @@ def cli():
     pass
 
 
+def common_options(required):
+    def option(*args, **kwargs):
+        kw = kwargs.copy()
+        kw["required"] = False
+        for a in args:
+            if a in required:
+                kw["required"] = True
+        return click.option(*args, **kw)
+
+    options = [
+        option("--git-repo", help="Git repository"),
+        option("--git-ref", help="Git reference"),
+        option("--git-sha", help="Git commit"),
+        option(
+            "--target-arch",
+            help="Target architecture [arm64|arm|x86|i386|mips|arc|riscv]",
+        ),
+        option(
+            "--kconfig",
+            multiple=True,
+            help="Kernel kconfig arguments (may be specified multiple times)",
+        ),
+        option("--toolchain", help="Toolchain [gcc-8|gcc-9|clang-8|clang-9]"),
+        option(
+            "--kconfig-allconfig",
+            help=(
+                "Argument used only with allyesconfig/allmodconfig/allnoconfig/randconfig."
+                "The argument is a path to a file with specific config symbols which you want to override"
+            ),
+        ),
+        option(
+            "--json-out",
+            help="Write json build status out to a named file path",
+            type=click.File("w", encoding="utf-8"),
+        ),
+        option(
+            "-q",
+            "--quiet",
+            default=False,
+            is_flag=True,
+            help="Supress all informational output; prints only the download URL for the build",
+        ),
+    ]
+
+    def wrapper(f):
+        for opt in options:
+            f = opt(f)
+        return f
+
+    return wrapper
+
+
 @cli.command()
-@click.option("--git-repo", required=True, help="Git repository")
-@click.option("--git-ref", required=True, help="Git reference")
-@click.option(
-    "--target-arch",
-    required=True,
-    help="Target architecture [arm64|arm|x86|i386|mips|arc|riscv]",
-)
-@click.option(
-    "--kconfig",
-    required=True,
-    multiple=True,
-    help="Kernel kconfig arguments (may be specified multiple times)",
-)
-@click.option(
-    "--toolchain", required=True, help="Toolchain [gcc-8|gcc-9|clang-8|clang-9]"
-)
-@click.option(
-    "--kconfig-allconfig",
-    required=False,
-    help=(
-        "Argument used only with allyesconfig/allmodconfig/allnoconfig/randconfig."
-        "The argument is a path to a file with specific config symbols which you want to override"
-    ),
-)
-@click.option(
-    "--json-out",
-    required=False,
-    help="Write json build status out to a named file path",
-    type=click.File("w", encoding="utf-8"),
-)
-@click.option(
-    "-q",
-    "--quiet",
-    default=False,
-    is_flag=True,
-    help="Supress all informational output; prints only the download URL for the build",
-)
-def build(
-    git_repo,
-    git_ref,
-    target_arch,
-    kconfig,
-    toolchain,
-    kconfig_allconfig=None,
-    json_out=None,
-    quiet=False,
-):
+@common_options(required=["--git-repo", "--target-arch", "--kconfig", "--toolchain"])
+def build(json_out=None, quiet=False, **build_params):
     quiet_output(quiet)
 
     auth = get_config()
     token = get_auth_token(auth)
     kbapi_url = auth.get_kbapi_url()
-    build = tuxbuild.build.Build(
-        git_repo=git_repo,
-        git_ref=git_ref,
-        target_arch=target_arch,
-        kconfig=kconfig,
-        toolchain=toolchain,
-        token=token,
-        kbapi_url=kbapi_url,
-        kconfig_allconfig=kconfig_allconfig,
+    try:
+        build = tuxbuild.build.Build(**build_params, token=token, kbapi_url=kbapi_url)
+    except AssertionError as e:
+        error(e)
+    info(
+        "Building Linux Kernel {} at {}".format(
+            build.git_repo, build.git_ref or build.git_sha
+        )
     )
-    info("Building Linux Kernel {} at {}".format(git_repo, git_ref))
     try:
         build.build()
     except tuxbuild.exceptions.BadRequest as e:
@@ -244,70 +249,16 @@ def get_tux_config(url, retries=3, sleep=3):
 
 
 @cli.command()
+@click.option("--set-name", required=True, help="Set name")
 @click.option(
     "--tux-config",
     default=get_default_buildset(),
     help="Path or a web URL to tuxbuild config file",
 )
-@click.option("--set-name", required=True, help="Set name")
-@click.option("--git-repo", required=True, help="Git repository")
-@click.option("--git-ref", required=True, help="Git reference")
-@click.option(
-    "--target-arch",
-    required=False,
-    help="Target architecture [arm64|arm|x86|i386|mips|arc|riscv]",
-)
-@click.option(
-    "--kconfig",
-    required=False,
-    multiple=True,
-    help="Kernel kconfig arguments (may be specified multiple times)",
-)
-@click.option(
-    "--toolchain", required=False, help="Toolchain [gcc-8|gcc-9|clang-8|clang-9]"
-)
-@click.option(
-    "--kconfig-allconfig",
-    required=False,
-    help=(
-        "Argument used only with allyesconfig/allmodconfig/allnoconfig/randconfig."
-        "The argument is a path to a file with specific config symbols which you want to override"
-    ),
-)
-@click.option(
-    "--json-out",
-    required=False,
-    help="Write json build status out to a named file path",
-    type=click.File("w", encoding="utf-8"),
-)
-@click.option(
-    "-q",
-    "--quiet",
-    default=False,
-    is_flag=True,
-    help="Supress all informational output; prints only the download URLs for the builds",
-)
-def build_set(
-    tux_config,
-    set_name,
-    git_repo=None,
-    git_ref=None,
-    target_arch=None,
-    kconfig=(),
-    kconfig_allconfig=None,
-    toolchain=None,
-    json_out=None,
-    quiet=None,
-):
+@common_options(required=["--git-repo"])
+def build_set(tux_config, set_name, json_out=None, quiet=None, **build_params):
     quiet_output(quiet)
 
-    params = {}
-    params["git_repo"] = git_repo
-    params["git_ref"] = git_ref
-    params["target_arch"] = target_arch
-    params["kconfig"] = kconfig
-    params["kconfig_allconfig"] = kconfig_allconfig
-    params["toolchain"] = toolchain
     config = get_config()
     token = get_auth_token(config)
     kbapi_url = config.get_kbapi_url()
@@ -318,7 +269,6 @@ def build_set(
         with open(tux_config, "r") as f:
             tux_config_contents = yaml.safe_load(f)
 
-    info("Building Linux Kernel build set {}".format(set_name))
     # Find build named set_name
     build_list = None
     for bs in tux_config_contents.get("sets"):
@@ -337,36 +287,15 @@ def build_set(
     # before submitting builds
     build_objects = []
     for b in build_list:
-        for param in ["git_repo", "git_ref", "target_arch", "kconfig", "toolchain"]:
-            if params[param]:
-                b[param] = params[param]
-            elif param not in b:
-                error(
-                    "No {} found in command line or in the set {} in {}: {}".format(
-                        param, set_name, tux_config, b
-                    )
-                )
-
-        # kconfig_allconfig is optional api parameter hence it may not be defined
-        # in cli or the set. We need to explicitly set it to None
-        if params.get("kconfig_allconfig") is not None:
-            b["kconfig_allconfig"] = params.get("kconfig_allconfig")
-        elif "kconfig_allconfig" not in b:
-            b["kconfig_allconfig"] = None
-
-        build_objects.append(
-            tuxbuild.build.Build(
-                git_repo=b["git_repo"],
-                git_ref=b["git_ref"],
-                target_arch=b["target_arch"],
-                kconfig=b["kconfig"],
-                toolchain=b["toolchain"],
-                token=token,
-                kbapi_url=kbapi_url,
-                kconfig_allconfig=b["kconfig_allconfig"],
-            )
-        )
+        build_opts = build_params.copy()
+        build_opts.update(b)
+        try:
+            build = tuxbuild.build.Build(**build_opts, token=token, kbapi_url=kbapi_url)
+            build_objects.append(build)
+        except AssertionError as e:
+            error(e)
 
+    info("Building Linux Kernel build set {}".format(set_name))
     build_set = tuxbuild.build.BuildSet(build_objects, token, kbapi_url)
 
     try:
